@@ -10,6 +10,7 @@ import java.util.Properties;
 import org.codehaus.plexus.util.FileUtils;
 import org.apache.maven.plugin.AbstractMojo;
 import org.apache.maven.plugin.MojoExecutionException;
+import org.debian.maven.repo.ListOfPOMs;
 import org.debian.maven.repo.POMCleaner;
 import org.debian.maven.repo.POMTransformer;
 
@@ -41,6 +42,22 @@ public class SysInstallMojo extends AbstractMojo
    * @readonly
    */
   private String artifactId;
+  
+  /**
+   * destGroupId
+   * 
+   * @parameter expression="${project.groupId}"
+   * @required
+   */
+  private String destGroupId;
+
+  /**
+   * destArtifactId
+   * 
+   * @parameter expression="${project.artifactId}"
+   * @required
+   */
+  private String destArtifactId;
 
   /**
    * version
@@ -89,6 +106,7 @@ public class SysInstallMojo extends AbstractMojo
    * @parameter expression="${debian.package}"
    */
   private String debianPackage;
+  private String destPackage;
 
   /**
    * @parameter expression="${maven.rules}" default-value="maven.rules"
@@ -104,6 +122,12 @@ public class SysInstallMojo extends AbstractMojo
    */
   private File repoDir;
 
+    /**
+     * Install the jar to /usr/share/java if true. Default is true
+     * @parameter expression="${install.to.usj}" default-value="true"
+     */
+  private boolean installToUsj = true;
+
   // ----------------------------------------------------------------------
   // Public methods
   // ----------------------------------------------------------------------
@@ -129,6 +153,11 @@ public class SysInstallMojo extends AbstractMojo
   {
       return artifactId;
   }
+  
+  protected String getDestArtifactId()
+  {
+      return destArtifactId;
+  }
 
   protected String getVersion()
   {
@@ -150,6 +179,11 @@ public class SysInstallMojo extends AbstractMojo
       return debianPackage;
   }
 
+  protected String getDestPackage()
+  {
+      return destPackage;    
+  }
+
   /**
    * optional destination prefix, empty by default
    */
@@ -161,17 +195,25 @@ public class SysInstallMojo extends AbstractMojo
   /**
    * returns e.g. /org/debian/maven/maven-debian-plugin/0.1/
    */
-  private String repoPath()
+  protected final String repoPath()
   {
     return "/" + groupId.replace( '.', '/' ) + "/" + artifactId + "/" + version + "/";
   }
+  
+  /**
+   * returns e.g. /org/debian/maven/maven-debian-plugin/0.1/
+   */
+  protected final String destRepoPath()
+  {
+    return "/" + destGroupId.replace( '.', '/' ) + "/" + destArtifactId + "/" + version + "/";
+  }
 
   /**
    * returns e.g. /org/debian/maven/maven-debian-plugin/debian/
    */
-  private String debianRepoPath()
+  protected final String debianRepoPath()
   {
-    return "/" + groupId.replace( '.', '/' ) + "/" + artifactId + "/" + debianVersion + "/";
+    return "/" + destGroupId.replace( '.', '/' ) + "/" + destArtifactId + "/" + debianVersion + "/";
   }
 
   /**
@@ -179,7 +221,7 @@ public class SysInstallMojo extends AbstractMojo
    */
   protected String fullRepoPath()
   {
-    return packagePath() + "/usr/share/maven-repo" + repoPath();
+    return packagePath() + "/usr/share/maven-repo" + destRepoPath();
   }
 
   /**
@@ -194,10 +236,15 @@ public class SysInstallMojo extends AbstractMojo
   {
     return artifactId + "-" + version + ".pom";
   }
+  
+  protected String destPomName()
+  {
+    return destArtifactId + "-" + version + ".pom";
+  }
 
   protected String debianPomName()
   {
-    return artifactId + "-" + debianVersion + ".pom";
+    return destArtifactId + "-" + debianVersion + ".pom";
   }
 
   private String pomSrcPath()
@@ -227,7 +274,7 @@ public class SysInstallMojo extends AbstractMojo
 
   private String pomDestPath()
   {
-    return fullRepoPath() + pomName();
+    return fullRepoPath() + destPomName();
   }
 
   private String debianPomDestPath()
@@ -239,28 +286,33 @@ public class SysInstallMojo extends AbstractMojo
   {
     return artifactId + "-" + version + ".jar";
   }
+  
+  protected String destJarName()
+  {
+    return destArtifactId + "-" + version + ".jar";
+  }
 
   protected String debianJarName()
   {
-    return artifactId + "-" + debianVersion + ".jar";
+    return destArtifactId + "-" + debianVersion + ".jar";
   }
 
-  private String fullJarName()
+  protected final String fullJarName()
   {
     return jarDir + "/" + jarName();
   }
 
-  private String jarDestPath()
+  protected final String jarDestPath()
   {
-    return fullRepoPath() + jarName();
+    return fullRepoPath() + destJarName();
   }
 
-  private String jarDestRelPath()
+  protected final String jarDestRelPath()
   {
-    return "../" + version + "/" + jarName();
+    return "../" + version + "/" + destJarName();
   }
 
-  private String debianJarDestPath()
+  protected final String debianJarDestPath()
   {
     return debianFullRepoPath() + debianJarName();
   }
@@ -268,19 +320,19 @@ public class SysInstallMojo extends AbstractMojo
   /** 
    * jar file name without version number
    */
-  private String compatName()
+  protected final String compatName()
   {
-    return artifactId + ".jar";
+    return destArtifactId + ".jar";
   }
 
-  private String compatSharePath()
+  protected final String compatSharePath()
   {
     return packagePath() + "/usr/share/java/";
   }
 
-  private String compatRelPath()
+  protected final String compatRelPath()
   {
-    return "../maven-repo" + repoPath() + jarName();
+    return "../maven-repo" + destRepoPath() + destJarName();
   }
 
   protected String fullCompatPath()
@@ -290,7 +342,7 @@ public class SysInstallMojo extends AbstractMojo
 
   protected String versionedFullCompatPath()
   {
-    return compatSharePath() + jarName();
+    return compatSharePath() + destJarName();
   }
 
   /**
@@ -357,50 +409,65 @@ public class SysInstallMojo extends AbstractMojo
   private void cleanPom()
   {
     File pomOptionsFile = new File(debianDir, debianPackage + ".poms");
-    Map pomOptions = POMTransformer.getPomOptions(pomOptionsFile);
+    ListOfPOMs listOfPOMs = new ListOfPOMs(pomOptionsFile);
+
     // Use the saved pom before cleaning as it was untouched by the transform operation
-    File pom = new File(pomSrcPath() + ".save");
-    File originalPom = new File(pomSrcPath()).getAbsoluteFile();
-    if (! pom.exists())
+    String pomPath = pomSrcPath() + ".save";
+    File pomFile = new File(pomPath);
+    String originalPomPath = pomSrcPath();
+    File originalPom = new File(originalPomPath);
+    if (! pomFile.exists())
     {
-        pom = originalPom;
+        pomFile = originalPom;
+        pomPath = originalPomPath;
     }
 
-    String pomOption = (String) pomOptions.get(originalPom);
+    String relativePomPath = originalPom.getAbsolutePath();
+    relativePomPath = relativePomPath.substring(debianDir.getParentFile().getAbsolutePath().length() + 1);
+
+    ListOfPOMs.POMOptions pomOption = listOfPOMs.getPOMOptions(relativePomPath);
+
+    if (pomOption != null && pomOption.isIgnore()) {
+        throw new RuntimeException("POM file " + pomFile + " should be ignored");
+    }
+
+    destPackage = debianPackage;
+    if (pomOption != null && pomOption.getDestPackage() != null) {
+      destPackage = pomOption.getDestPackage();
+    }
 
     List params = new ArrayList();
     params.add("--keep-pom-version");
-    params.add("--package=" + debianPackage);
+      
+    params.add("--package=" + destPackage);
     String mavenRulesPath = new File(debianDir, mavenRules).getAbsolutePath();
     params.add("--rules=" + mavenRulesPath);
 
-    System.out.println("Cleaning pom file: " + pom + " with options:");
-    System.out.println("\t--keep-pom-version --package=" + debianPackage);
+    System.out.println("Cleaning pom file: " + pomFile + " with options:");
+    System.out.println("\t--keep-pom-version --package=" + destPackage);
     System.out.println("\t--rules=" + mavenRulesPath);
 
     // add optional --no-parent option
-    if (pomOption != null && !pomOption.isEmpty()) {
-        params.add(pomOption);
-        System.out.println("\t" + pomOption);
+    if (pomOption != null && pomOption.isNoParent()) {
+        params.add("--no-parent");
+        System.out.println("\t--no-parent");
     }
     
-    params.add(pom.getAbsolutePath());
+    params.add(pomFile.getAbsolutePath());
     params.add(cleanedPomSrcPath());
     params.add(cleanedPomPropertiesSrcPath());
 
     POMCleaner.main((String[]) params.toArray(new String[params.size()]));
 
-    // read debian version
-    if (debianVersion == null)
-    {
-      Properties pomProperties = new Properties();
-      try {
-        pomProperties.load(new FileReader(cleanedPomPropertiesSrcPath()));
-      } catch (IOException ex) {
-        ex.printStackTrace();
-      }
-      debianVersion = pomProperties.getProperty("debianVersion");
+    Properties pomProperties = new Properties();
+    try {
+      pomProperties.load(new FileReader(cleanedPomPropertiesSrcPath()));
+    } catch (IOException ex) {
+      ex.printStackTrace();
     }
+    destGroupId = pomProperties.getProperty("groupId");
+    destArtifactId = pomProperties.getProperty("artifactId");
+    debianVersion = pomProperties.getProperty("debianVersion");
 
     if (debianVersion != null && !debianVersion.equals(version))
     {
@@ -446,6 +513,16 @@ public class SysInstallMojo extends AbstractMojo
     }
   }
 
+  /**
+     * Prepare the destination  directories: remove the directory symlinks that were created
+     * by copy-repo.sh if they exist as they point to a directory owned by root and that cannot
+     * be modified.
+     */
+  protected void prepareDestDirs() {
+      // Simply try to delete the path. If it's a symlink, it will work, otherwise delete() returns false
+      new File(fullRepoPath()).delete();
+      new File(debianFullRepoPath()).delete();
+  }
   /**
    * do the actual work
    */
@@ -453,8 +530,11 @@ public class SysInstallMojo extends AbstractMojo
   {
     //initProperties();
     cleanPom();
+    prepareDestDirs();
     copyPom();
     copyJar();
-    symlinkJar();
+    if (installToUsj) {
+      symlinkJar();
+    }
   }
 }
